// =====================================================================
//  main.c
// =====================================================================

//  Author:         (c) 2013 Camil Demetrescu
//  License:        See the end of this file for license information
//  Created:        September 20, 2013

//  Last changed:   $Date: 2013/09/20 15:00:07 $
//  Changed by:     $Author: demetres $
//  Revision:       $Revision: 1.00 $


#include "bintree.h"
#include <stdio.h>
#include <string.h>


// ---------------------------------------------------------------------
// make_search_tree
// --------------------------------------------------------------------
bintree* make_search_tree() {
	return
		bintree_new(
			bintree_new(
				bintree_new(
                    bintree_new(
                        NULL,
                        "abstraction",
                        NULL
                    ),
                    "automorphism",
                    NULL
				),
				"boat",
				bintree_new(
                    bintree_new(
                        NULL,
                        "carrier",
                        NULL
                    ),
                    "cruise",
                    NULL
				)
			),
			"darwinism",
			bintree_new(
				bintree_new(
                    bintree_new(
                        NULL,
                        "drone",
                        NULL
                    ),
                    "ecosystem",
                    bintree_new(
                        NULL,
                        "fantasy",
                        NULL
                    )
				),
				"frontier",
				bintree_new(
                    bintree_new(
                        NULL,
                        "garage",
                        NULL
                    ),
                    "gratitude",
                    NULL
				)
			)	
		);
}


// ---------------------------------------------------------------------
// print_tree
// --------------------------------------------------------------------
void print_tree(bintree* root, int indent) {
	int i;
    if (root == NULL) return;
    for (i=0; i<indent; i++) printf(" ");
	printf("%s\n", (char*)root->elem);
    print_tree(root->left,  indent+4);
    print_tree(root->right, indent+4);
}


// ---------------------------------------------------------------------
// main
// ---------------------------------------------------------------------
int main() {

    // make sample tree
    bintree* t = make_search_tree();

    // display tree content
    printf("Tree content before removing leaves:\n");
    print_tree(t,0);

	// remove leaves
	bintree_remove_leaves(t);

    // display tree content
    printf("Tree content after removing leaves:\n");
    print_tree(t,0);

    // deallocate tree
    bintree_delete(t);

    return 0;
}


// Copyright (C) 2013 Camil Demetrescu

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
// USA
