// =====================================================================
//  bintree.h
// =====================================================================

//  Author:         (c) 2013 Camil Demetrescu
//  License:        See the end of this file for license information
//  Created:        September 20, 2013

//  Last changed:   $Date: 2013/09/20 15:00:07 $
//  Changed by:     $Author: demetres $
//  Revision:       $Revision: 1.00 $

#include "bintree.h"
#include <stdlib.h>
#include <assert.h>

// ---------------------------------------------------------------------
// bintree_new
// --------------------------------------------------------------------
bintree* bintree_new(bintree* left, void* elem, bintree* right) {
	bintree* t = malloc(sizeof(bintree));
	assert(t != NULL);
	t->left  = left;
	t->elem  = elem;
	t->right = right;
	return t;
}


// ---------------------------------------------------------------------
// _aux_remove_leaves
// --------------------------------------------------------------------
static int _aux_remove_leaves(bintree* root) {
	if (root==NULL) return 0;
	if (root->left==NULL && root->right==NULL) {
		free(root);
		return 1;
	}
	if (_aux_remove_leaves(root->left))  root->left  = NULL;
	if (_aux_remove_leaves(root->right)) root->right = NULL;
	return 0;
}


// ---------------------------------------------------------------------
// bintree_remove_leaves
// --------------------------------------------------------------------
void bintree_remove_leaves(bintree* root) {
	_aux_remove_leaves(root);
}


// ---------------------------------------------------------------------
// bintree_delete
// --------------------------------------------------------------------
void bintree_delete(bintree* root) {
	if (root == NULL) return;
	bintree_delete(root->left);
	bintree_delete(root->right);
	free(root);
}


// Copyright (C) 2013 Camil Demetrescu

// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
// USA
